==> hippoagentsdk-0.0.2-sources.jar: com/hippoagent/activities/ChannelJourney.kt <==
package com.hippoagent.activities

import android.os.Bundle
import com.hippoagent.R
import com.hippoagent.fragments.ChannelJourneyFragment
import kotlinx.android.synthetic.main.activity_payment.*

/**
 * Created by gurmail on 2019-09-09.
 * @author gurmail
 */
class ChannelJourney: FuguBaseActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_payment)

        setSupportActionBar(my_toolbar)
        setToolbar(my_toolbar, getString(R.string.channel_journey))

        my_toolbar.setNavigationOnClickListener {
            onBackPressed()
        }

        val data = intent.getStringExtra("cJourneyList")
        onChannelJourneyFragment(data)
    }

    override fun onResume() {
        super.onResume()
    }

    override fun onPause() {
        super.onPause()
    }

    override fun onBackPressed() {
        if(supportFragmentManager.backStackEntryCount < 2) {
            finish()
        } else {
            super.onBackPressed()
        }
    }

    private fun onChannelJourneyFragment(data: String) {
        var fragment = ChannelJourneyFragment()
        val bundle = Bundle()
        bundle.putString("data", data)
        fragment.arguments = bundle

        supportFragmentManager.beginTransaction()
                .add(R.id.main_layout, fragment, ChannelJourneyFragment::class.java.simpleName)
                .addToBackStack(ChannelJourneyFragment::class.java.simpleName)
                .commitAllowingStateLoss()
    }
}

==> hippoagentsdk-0.1.3-sources.jar: com/hippoagent/activities/ChannelJourney.kt <==
package com.hippoagent.activities

import android.os.Bundle
import com.hippoagent.R
import com.hippoagent.fragments.ChannelJourneyFragment
import com.hippoagent.langs.Restring
import kotlinx.android.synthetic.main.activity_payment.*

/**
 * Created by gurmail on 2019-09-09.
 * @author gurmail
 */
class ChannelJourney: FuguBaseActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_payment)

        setSupportActionBar(my_toolbar)
        setToolbar(my_toolbar, Restring.getString(this@ChannelJourney, R.string.channel_journey))

        my_toolbar.setNavigationOnClickListener {
            onBackPressed()
        }

        val data = intent.getStringExtra("cJourneyList")
        onChannelJourneyFragment(data)
    }

    override fun onResume() {
        super.onResume()
    }

    override fun onPause() {
        super.onPause()
    }

    override fun onBackPressed() {
        if(supportFragmentManager.backStackEntryCount < 2) {
            finish()
        } else {
            super.onBackPressed()
        }
    }

    private fun onChannelJourneyFragment(data: String) {
        var fragment = ChannelJourneyFragment()
        val bundle = Bundle()
        bundle.putString("data", data)
        fragment.arguments = bundle

        supportFragmentManager.beginTransaction()
                .add(R.id.main_layout, fragment, ChannelJourneyFragment::class.java.simpleName)
                .addToBackStack(ChannelJourneyFragment::class.java.simpleName)
                .commitAllowingStateLoss()
    }
}
